import { staticMessages } from '~/driven/utils/constants/staticMessages';
import { apiUrls } from '~/driven/utils/configs/appConfig';
import { PhonenumberAuthDTOReturnType } from '~/business-logic/generic/admin-user/authentication/phonnumber-auth/data/dto/phonenumberDto';
import { IPhonenumberAuthPort } from '~/business-logic/generic/admin-user/authentication/phonnumber-auth/port';
import { HttpOptionsType } from '~/driven/boundaries/http-boundary/protocols';
import { HTTPPovider } from '~/driven/boundaries/http-boundary/httpBoundary';
import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';

const authAdminPhoneNumberDriven = (
  userAdmin: AdminUserModel | null,
  updateAccessToken: (newAccessToken: string) => void,
  navigateToAuth: () => void,
): IPhonenumberAuthPort => {
  // make http handler ready for the phone number
  const wrongPhoneNumberMessage = staticMessages.global.errors.phonenumber;

  const httpProvider = new HTTPPovider(
    {
      accessToken: userAdmin && userAdmin?.adminUserData.accessToken && null,
      refreshToken: userAdmin && userAdmin?.adminUserData.refreshToken && null,
    },
    updateAccessToken,
    navigateToAuth,
  );
  const httpHandler = (data: PhonenumberAuthDTOReturnType) => {
    const url = apiUrls.generic.authPhonenumber;
    const options: HttpOptionsType = {
      url,
      headers: {
        'Content-Type': 'application/json',
      },
      method: 'POST',
      data,
    };
    return httpProvider.request<string>(options);
  };

  return {
    httpHandler,
    wrongPhoneNumberMessage,
  };
};

export default authAdminPhoneNumberDriven;
