import { useCallback, useEffect, useMemo, useState } from 'react';
import useGetPlaceList from '../../common/hooks/useGetPlaceList';
import { PlaceFormState, placeTypes } from '../view/protocol';
import { ICreatePlaceVm, initialPlaceFormState } from './protocols';

const onChangeInputStateHandlers = (setFormState: React.Dispatch<React.SetStateAction<PlaceFormState>>) => {
  const handleNameSetState = (_name: string, newValue: string) =>
    setFormState((prev) => ({ ...prev, placeName: newValue }));

  const handlePlaceTypeSetState = (newValue: `${placeTypes}`) =>
    setFormState((prev) => ({ ...prev, placeTypes: newValue }));

  const handleParentIdSetState = (newValue: string, label: string) =>
    setFormState((prev) => ({ ...prev, parentId: { value: newValue, label } }));

  return {
    handleNameSetState,
    handlePlaceTypeSetState,
    handleParentIdSetState,
  };
};

const resetParentIdOnChangePlaceType = (setFormState: React.Dispatch<React.SetStateAction<PlaceFormState>>) => {
  setFormState((prev) => ({ ...prev, parentId: { label: '', value: '' } }));
};

const useCreatePlaceVm = (dependencies: ICreatePlaceVm) => {
  const { getInputOptions } = dependencies;
  const { getParentIds, getPlaceType } = getInputOptions;
  const [formState, setFormState] = useState<PlaceFormState>(initialPlaceFormState);

  const { handleNameSetState, handleParentIdSetState, handlePlaceTypeSetState } = useMemo(
    () => onChangeInputStateHandlers(setFormState),
    [],
  );

  useEffect(() => resetParentIdOnChangePlaceType(setFormState), [formState.placeTypes]);

  const getPlaceList = useCallback(() => useGetPlaceList()(), []);
  const places = getPlaceList();

  const placeTypesOptions = useMemo(() => getPlaceType(), []);
  const parentIdsOptions = useMemo(() => {
    if (!places.data) return [];
    return getParentIds(formState.placeTypes, places.data);
  }, [formState.placeTypes, places]);

  return {
    formStateData: {
      formState,
      setFormState,
    },
    inputStateHandlers: {
      name: handleNameSetState,
      parentId: handleParentIdSetState,
      placeType: handlePlaceTypeSetState,
    },
    selectBoxOptions: {
      placeTypesOptions,
      parentIdsOptions,
      isParentIdLoading: places.isLoading,
    },
  };
};

export default useCreatePlaceVm;
